#ifndef NT2_INCLUDE_FUNCTIONS_ATAN_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_ATAN_HPP_INCLUDED

#include <nt2/trigonometric/include/functions/atan.hpp>

#endif
